@@ -1,4 +1,4 @@
-from controller import Emitter, Camera, GPS
+from controller import Emitter, Camera, GPS, Gyro
 from flockai.PyCatascopia.probelib.ProcessProbe import ProcessProbe
 from flockai.models.drones.autopilot_controlled_drone import AutopilotControlledDrone
 from flockai.models.drones.keyboard_controller_drone import KeyboardControlledDrone
@@ -176,11 +176,17 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
 class AutopilotMavic2DJI(AutopilotControlledDrone):
     def __init__(self, devices, probe: FlockAIProbe=None, model=None):
+        self.P_COMM = 8.4
+        self.DJI_A3_FC = 8
+        self.RASPBERRY_PI_4B_IDLE = 4
+        self.RASPBERRY_PI_4B_ACTIVE = 8
         super().__init__(devices)
 
-    def get_coordinates(self):
-        gps: GPS = self.devices['gps']['device']
-        return gps.getValues()
+
+
+    def get_angular_velocity(self):
+        gyro: Gyro = self.devices['gyro']['device']
+        return gyro.getValues()
 
     def run(self):
         # Wait a second before starting
@@ -190,5 +196,5 @@ class AutopilotMavic2DJI(AutopilotControlledDrone):
 
         while self.step(self.basic_time_step) != -1:
             # For now just actuate
-            print(self.get_coordinates())
+            print(self.get_distance_from_target())
             self.actuate()
